.. include:: ../../README.rst

Table of Contents
=================

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   gettingstarted/installation
   gettingstarted/syntax_examples
   gettingstarted/tutorials/index.rst

.. toctree::
   :maxdepth: 2
   :caption: Syntax Rules

   syntax/introduction
   syntax/basic_graph_description
   syntax/fragments
   syntax/multiple_resolutions
   syntax/chirality

.. toctree::
   :maxdepth: 2
   :caption: API

   api/cgsmiles.resolve
   api/cgsmiles.drawing
   api/cgsmiles.sample
   api/cgsmiles.write_cgsmiles
   api/cgsmiles.read_cgsmiles
   api/cgsmiles.read_fragments
   api/cgsmiles.graph_utils
   api/cgsmiles.pysmiles_utils
   api/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
